==> tree-sitter-legesher-python-0.15.4.tgz: package/.github/PULL_REQUEST_TEMPLATE.md <==
<!---
Thanks for the pull request, kindly include a summary of the change(s) and refer the issue(s) being fixed, also include relevant motivation and context. Please make sure to list any dependencies (if any) that are required for this change.
--->

> Make sure you go through the [Contributing guide](https://github.com/legesher/legesher/blob/master/CONTRIBUTING.md).

> Please delete options that are not relevant.

## Title
<!---
Add #(issue no.)
--->
This pull request (PR) is made in reference to: 

<!---
KEY REMINDER
This project only accepts pull requests related to open issues
- If suggesting a new feature or change, please discuss it in an issue first.  
- If fixing a bug, there should be an issue describing it with steps to reproduce.
--->

## Description
<!---
Describe your changes in detail
--->
> What does this PR do?

> Recommendations for how to test this?

## Motivation and Context
<!---
Why is this change required? What problem does it solve? 
--->

# Checklist:
<!--- 
[ ] implies unchecked
[x] implies checked
Tick the appropriate boxes (leave if irrelevant)
--->
- [ ] My code follows the style guidelines of this project
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published in downstream modules

## Testing
<!---
Include any details about your testing process
--->
* [ ] My submission passes the tests?
  - If you did additional testing, please describe in detail how you tested your changes
* [ ] I added new tests for core changes, as applicable?

### Screenshots (if appropriate):
<!--- you can also upload a GIF --->

==> tree-sitter-legesher-python-0.19.0.tgz: package/.github/PULL_REQUEST_TEMPLATE.md <==
<!---
Thanks for the pull request, kindly include a summary of the change(s) and refer the issue(s) being fixed, also include relevant motivation and context. Please make sure to list any dependencies (if any) that are required for this change.
--->

> Make sure you go through the [Contributing guide](https://docs.legesher.io/the-official-things/contributing-guidelines).

> Please delete options that are not relevant.

## Title

<!---
Add #(issue no.)
--->

This pull request (PR) is made in reference to:

<!---
KEY REMINDER
This project only accepts pull requests related to open issues
- If suggesting a new feature or change, please discuss it in an issue first.
- If fixing a bug, there should be an issue describing it with steps to reproduce.
--->

## Description

<!---
Describe your changes in detail
--->

> What does this PR do?

> Recommendations for how to test this?

## Motivation and Context

<!---
Why is this change required? What problem does it solve?
--->

# Checklist:

<!---
[ ] implies unchecked
[x] implies checked
Tick the appropriate boxes (leave if irrelevant)
--->

- [ ] My code follows the style guidelines of this project
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published in downstream modules

## Testing

<!---
Include any details about your testing process
--->

- [ ] My submission passes the tests?
  - If you did additional testing, please describe in detail how you tested your changes
- [ ] I added new tests for core changes, as applicable?

### Screenshots (if appropriate):

<!--- you can also upload a GIF --->
